@@ -15,3 +15,7 @@ class TestAlias:
     def test_2(self, completion):
         assert completion == "foo='bar'"
         assert not completion.endswith(" ")
+
+    @pytest.mark.complete("alias ", trail="foo")
+    def test_alias_at_point(self, completion):
+        assert completion == "bar foo".split()
