@@ -12,7 +12,7 @@ class TestChmod:
     def test_2(self, completion):
         assert completion
 
-    @pytest.mark.complete("chmod -")
+    @pytest.mark.complete("chmod -", require_cmd=True)
     def test_3(self, completion):
         assert completion
 
