@@ -6,6 +6,6 @@ class TestChrpath:
     def test_1(self, completion):
         assert completion
 
-    @pytest.mark.complete("chrpath -")
+    @pytest.mark.complete("chrpath -", require_cmd=True)
     def test_2(self, completion):
         assert completion
