@@ -2,13 +2,11 @@ import pytest
 
 
 class TestDpkg:
-    @pytest.mark.complete("dpkg --c")
+    @pytest.mark.complete("dpkg --c", require_cmd=True)
     def test_1(self, completion):
         assert completion
 
-    @pytest.mark.complete(
-        "dpkg -L ", skipif='test -z "$(dpkg -l 2>/dev/null)"'
-    )
+    @pytest.mark.complete("dpkg -L ", xfail='test -z "$(dpkg -l 2>/dev/null)"')
     def test_2(self, completion):
         assert completion
 
