@@ -6,7 +6,7 @@ class TestFio:
     def test_1(self, completion):
         assert completion
 
-    @pytest.mark.complete("fio --")
+    @pytest.mark.complete("fio --", require_cmd=True)
     def test_2(self, completion):
         assert completion
 
