@@ -3,7 +3,9 @@ import pytest
 
 class TestLvdisplay:
     @pytest.mark.complete(
-        "lvdisplay --", skipif="! lvdisplay --help &>/dev/null"
+        "lvdisplay --",
+        require_cmd=True,
+        xfail="! lvdisplay --help &>/dev/null",
     )
     def test_1(self, completion):
         assert completion
