@@ -2,6 +2,6 @@ import pytest
 
 
 class TestMysqladmin:
-    @pytest.mark.complete("mysqladmin -")
+    @pytest.mark.complete("mysqladmin -", require_cmd=True)
     def test_1(self, completion):
         assert completion
