@@ -6,6 +6,12 @@ class TestNproc:
     def test_1(self, completion):
         assert not completion
 
-    @pytest.mark.complete("nproc -")
+    @pytest.mark.complete(
+        "nproc --",
+        xfail=(
+            "! nproc --help &>/dev/null || "
+            "! nproc --help 2>&1 | command grep -qF -- --help"
+        ),
+    )
     def test_2(self, completion):
         assert completion
