@@ -6,6 +6,8 @@ class TestPydocstyle:
     def test_1(self, completion):
         assert completion
 
-    @pytest.mark.complete("pydocstyle -", require_cmd=True)
+    @pytest.mark.complete(
+        "pydocstyle -", require_cmd=True, require_longopt=True
+    )
     def test_2(self, completion):
         assert completion
