@@ -2,6 +2,6 @@ import pytest
 
 
 class TestReadelf:
-    @pytest.mark.complete("readelf --")
+    @pytest.mark.complete("readelf --", require_cmd=True)
     def test_1(self, completion):
         assert completion
