@@ -5,4 +5,4 @@ import pytest
 class TestSbclMt:
     @pytest.mark.complete("sbcl-mt shared/default/")
     def test_1(self, completion):
-        assert completion == ["bar", "bar bar.d/", "foo", "foo foo.d/"]
+        assert completion == ["bar", "bar bar.d/", "foo", "foo.d/"]
