@@ -6,14 +6,14 @@ class TestScrub:
     def test_1(self, completion):
         assert completion
 
-    @pytest.mark.complete("scrub -")
+    @pytest.mark.complete("scrub -", require_cmd=True)
     def test_2(self, completion):
         assert completion
 
     # Not all scrub versions list available patterns in --help output
     @pytest.mark.complete(
         "scrub -p ",
-        skipif="! (scrub --help 2>&1 || :) | " "command grep -q ^Available",
+        xfail="! (scrub --help 2>&1 || :) | command grep -q ^Available",
     )
     def test_3(self, completion):
         assert completion
