@@ -2,6 +2,6 @@ import pytest
 
 
 class TestTouch:
-    @pytest.mark.complete("touch --", skipif="! touch --help &>/dev/null")
+    @pytest.mark.complete("touch --", require_longopt=True)
     def test_1(self, completion):
         assert completion
