@@ -2,6 +2,6 @@ import pytest
 
 
 class TestWebmitm:
-    @pytest.mark.complete("webmitm -")
+    @pytest.mark.complete("webmitm -", require_cmd=True)
     def test_1(self, completion):
         assert completion
